function [S,E]=Schrodinger1D;

N=150;

x=0.3;
DE=-0.79*x;                 % ev
mAlGaAs=(0.063+0.083*x);    % in m0 (electron mass)
mGaAs=0.063;                % in m0 (electron mass) 

delta=1e-10;      % meter

mass=[ones(1,N)*mAlGaAs ones(1,N)*mGaAs ones(1,N)*mAlGaAs];
%V=[zeros(1,N) ones(1,N)*DE zeros(1,N)];
%V=[zeros(1,N) (1:N)*DE/N/2+DE/2 zeros(1,N)];

Nc=round(length(mass)/2);
V=[zeros(1,N) ones(1,N)*DE zeros(1,N)];
V(Nc-30:Nc+30)=V(Nc-30:Nc+30)+0.1;



[S,E]=SolveSchrodinger1D(mass,V,delta);




%=======================================================================

function [S,E]=SolveSchrodinger1D(mass,V,delta);
% Solve 1D Schrodinger equation for given mass, potential and 
% Boundary condiction Pai(0)=Pai(L)=0

h=4.1356692e-15/2/pi;    % Planck constant
c=3e8;                   % Speed of light
m0=510999.06/c^2;        % electron mass in ev s
temp=-h^2/m0/delta^2/2;  

M=length(V);
T=zeros(M,M);
for I=1:M
    if I==1 
        T(I,I)=temp*(-2/mass(I))+V(I);
        T(I,I+1)=temp/mass(I);
    elseif I==M
        T(I,I-1)=temp/mass(I);
        T(I,I)=temp*(-2/mass(I))+V(I);
    else
        T(I,I-1)=temp*(1/mass(I)-0.25*(1/mass(I+1)-1/mass(I-1)));
        T(I,I)=temp*(-2/mass(I))+V(I);
        T(I,I+1)=temp*(1/mass(I)+0.25*(1/mass(I+1)-1/mass(I-1)));
    end        
end

% Eigen solver
[S,E]=eig(T);
[E1,Istate]=sort(diag(E));



% Total number of bound states
Nt=length(find(E1<=0))+1
RGB={'b','r','g','c','m','k','y'};
x=[0:M+1]*delta/1e-10;  % A


figure(1)
clf;

for I=1:Nt
    temp=[0 S(:,Istate(I))' 0];
    line('xdata',x,'ydata',temp,'color',RGB{I})
    
    mylegend{I}=['E:  ' num2str(E1(I)) ' ev'];
end

line('xdata',x,'ydata',[0 V 0],'color','b','linestyle','--','linewidth',2)
legend(mylegend);
xlabel('x (A)'); ylabel('Potential (ev)')
box on


figure(2)
plot(diff(S(:,Istate(1))))
